=== modified file 'docs/administration/authorization.rst'
--- docs/administration/authorization.rst	2011-08-13 20:41:38 +0000
+++ docs/administration/authorization.rst	2011-10-23 05:45:09 +0000
@@ -5,6 +5,11 @@
 have the resource. [1]_  Drizzle authorization is handled by plugins; there
 are no grant or privilege tables.
 
+The following authorization plugins are included with Drizzle:
+
+* :doc:`/plugins/regex_policy/index`
+* :doc:`/plugins/simple_user_policy/index`
+
 -------------------------------------------------------------------------------
 
 .. rubric:: Footnotes

=== added file 'docs/administration/drizzled.rst'
--- docs/administration/drizzled.rst	1970-01-01 00:00:00 +0000
+++ docs/administration/drizzled.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,97 @@
+.. program:: drizzled
+
+.. _drizzled_process:
+
+drizzled Process
+================
+
+.. _starting_and_stopping_drizzled:
+
+Starting and Stopping
+---------------------
+
+Although :program:`drizzled` can be started without any command line options
+or config files, you will certainly want to specify a minimal configuration
+to suite your particular system.  You should be familiar with the
+:ref:`drizzled_configuration` options and variables.
+
+Managing the :program:`drizzled` process depends on whether Drizzle
+was installed from a package or source.  Package installations can use
+the operating system's service managment programs, but source installations
+require simple scripts to manage Drizzle manually.
+
+Ubuntu
+^^^^^^
+
+Ubuntu uses the :program:`service` program to manage services.  To start
+and stop Drizzle from the command line:
+
+.. code-block:: bash
+
+   $ sudo service drizzle start
+   drizzle start/running, process 1431
+
+   $ sudo service drizzle stop
+   drizzle stop/waiting
+
+:file:`/etc/init/drizzle.conf` controls how :program:`service` starts
+and stops Drizzle.
+
+Manually
+^^^^^^^^
+
+If Drizzle was installed from source, or you want to manage
+:program:`drizzled` manually, you should create a script
+to start Drizzle from the command line.  For example, if Drizzle was
+installed to :file:`/usr/local/drizzle`, this script will start Drizzle
+with a minimal configuration:
+
+.. code-block:: bash
+
+   #!/bin/sh
+
+   BASEDIR="/usr/local/drizzle"
+
+   cd $BASEDIR
+
+   ./sbin/drizzled                     \
+      --basedir=$BASEDIR               \
+      --datadir=$BASEDIR/data          \
+      --pid-file=/var/run/drizzled.pid \
+   > $BASEDIR/var/log/drizzled.log 2>&1 &
+
+See :ref:`configuring_drizzle` for more information about setting additional
+command line options.
+
+Use the :ref:`drizzle_command_line_client` to stop Drizzle:
+
+.. code-block:: bash
+
+   $ drizzle --shutdown
+
+Or, execute ``shtudown``:
+
+.. code-block:: mysql
+
+   drizzle> shutdown;
+
+The ``shutdown`` command is case-sensitive.
+
+Output
+------
+
+:program:`drizzled` does *not* close or redirect output to ``STDOUT`` or
+``STDERR`` to a log file or logging facility like :program:`syslog`.
+You should redirect ``STDOUT`` and ``STDERR`` to a log file as in the above
+script example for starting Drizzle manually.
+
+Signaling
+---------
+
+====== ========
+Signal Response
+====== ========
+HUP    Ignore
+TERM   Shutdown
+====== ========
+

=== added file 'docs/administration/plugins.rst'
--- docs/administration/plugins.rst	1970-01-01 00:00:00 +0000
+++ docs/administration/plugins.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,47 @@
+.. program:: drizzled
+
+Plugins
+=======
+
+Plugins provide the majority of Drizzle's features: functions, system tables,
+replication, etc.  You should familiarize yourself with the
+:ref:`drizzled_plugin_options` and :doc:`/plugins/list`.
+
+.. _default_plugins:
+
+Default Plugins
+---------------
+
+Drizzle loads these plugins by default (see :option:`--plugin-load`):
+
+* auth_all (:ref:`auth_all_plugin`)
+* ascii (:ref:`ascii_plugin`)
+* benchmark (:ref:`benchmark_plugin`) 
+* charlength (:ref:`charlength_plugin`) 
+* compression (:ref:`compression_plugin`) 
+* connection_id (:ref:`connection_id_plugin`) 
+* crc32 (:ref:`crc32_plugin`) 
+* default_replicator (:ref:`default_replicator_plugin`) 
+* drizzle_protocol (:ref:`drizzle_protocol_plugin`)
+* errmsg_stderr (:ref:`errmsg_stderr_plugin`) 
+* filtered_replicator (:ref:`filtered_replicator_plugin`) 
+* hex_functions (:ref:`hex_functions_plugin`) 
+* innobase (:ref:`innobase_plugin`)
+* length (:ref:`length_plugin`) 
+* logging_stats (:ref:`logging_stats_plugin`)
+* math_functions (:ref:`math_functions_plugin`)
+* md5 (:ref:`md5_plugin`)
+* memory (:ref:`memory_plugin`)
+* multi_thread (:ref:`multi_thread_plugin`)
+* myisam (:ref:`myisam_plugin`)
+* mysql_protocol (:ref:`mysql_protocol_plugin`)
+* mysql_unix_socket_protocol (:ref:`mysql_unix_socket_protocol_plugin`)
+* rand_function (:ref:`rand_function_plugin`)
+* reverse_function (:ref:`reverse_function_plugin`)
+* sleep (:ref:`sleep_plugin`)
+* show_schema_proto (:ref:`show_schema_proto_plugin`)
+* substr_functions (:ref:`substr_functions_plugin`)
+* syslog (:ref:`syslog_plugin`)
+* transaction_log (:ref:`transaction_log_plugin`)
+* uuid_function (:ref:`uuid_function_plugin`)
+* version (:ref:`version_plugin`)

=== modified file 'docs/brief_history_of_drizzle.rst'
--- docs/brief_history_of_drizzle.rst	2011-03-08 03:47:42 +0000
+++ docs/brief_history_of_drizzle.rst	2011-10-23 05:45:09 +0000
@@ -1,5 +1,4 @@
-==========================
-A Brief History Of Drizzle
+A Brief History of Drizzle
 ==========================
 
 Drizzle came into being for both social and technical reasons.

=== modified file 'docs/clients/drizzle.rst'
--- docs/clients/drizzle.rst	2011-03-08 03:47:42 +0000
+++ docs/clients/drizzle.rst	2011-10-23 05:45:09 +0000
@@ -1,5 +1,31 @@
-Drizzle Commandline Client
-==========================
+
+.. _drizzle_command_line_client:
+
+drizzle Command Line Client
+===========================
 
 The :program:`drizzle` command line client is the primary program for ad-hoc
 connecting to and manipulating a Drizzle database.
+
+Errors
+------
+
+Various errors can occur when trying to use the Drizzle command line clients,
+this is a list of some of these and how to deal with them:
+
+.. _old-passwords-label:
+
+Old Password
+^^^^^^^^^^^^
+
+``drizzle_state_handshake_result_read:old insecure authentication mechanism not supported``
+
+This error happens because the Drizzle client is trying to connect to a MySQL
+server which has the password stored in the Old Password (or pre-MySQL-4.1)
+format.  This is typically seen when connecting to a stock RedHat or CentOS
+MySQL installation.
+
+To resolve this, look for the old-passwords option in your MySQL configuration
+and disable it.  Then update the password for the user you are trying to connect
+with using the ``SET PASSWORD`` syntax so that it can be re-recorded in the
+newer password format.

=== modified file 'docs/clients/drizzledump.rst'
--- docs/clients/drizzledump.rst	2011-03-08 03:47:42 +0000
+++ docs/clients/drizzledump.rst	2011-10-23 05:45:09 +0000
@@ -1,4 +1,4 @@
-Drizzledump Backup Tool
+drizzledump Backup Tool
 =======================
 
 Synopsis
@@ -26,7 +26,7 @@
 
 .. _drizzledump-options-label:
 
-Drizzledump options
+drizzledump Options
 -------------------
 
 The :program:`drizzledump` tool has several available options:
@@ -245,7 +245,7 @@
    **drizzle**
    The Drizzle protocol.
 
-Backups using Drizzledump
+Backups Using drizzledump
 -------------------------
 
 Backups of a database can be made very simply by running the following:
@@ -262,7 +262,7 @@
 
 .. _drizzledump-migration-label:
 
-MySQL Migration using Drizzledump
+MySQL Migration Using drizzledump
 ---------------------------------
 
 As of version 2010-09-27 there is the capability to migrate databases from

=== removed file 'docs/clients/errors.rst'
--- docs/clients/errors.rst	2011-02-15 22:03:42 +0000
+++ docs/clients/errors.rst	1970-01-01 00:00:00 +0000
@@ -1,24 +0,0 @@
-Drizzle Client Errors
-=====================
-
-Various errors can occur when trying to use the Drizzle command line clients,
-this is a list of some of these and how to deal with them:
-
-.. _old-passwords-label:
-
-Old Password Error
-------------------
-
-::
-
-   drizzle_state_handshake_result_read:old insecure authentication mechanism not supported
-
-This error happens because the Drizzle client is trying to connect to a MySQL
-server which has the password stored in the Old Password (or pre-MySQL-4.1)
-format.  This is typically seen when connecting to a stock RedHat or CentOS
-MySQL installation.
-
-To resolve this, look for the old-passwords option in your MySQL configuration
-and disable it.  Then update the password for the user you are trying to connect
-with using the ``SET PASSWORD`` syntax so that it can be re-recorded in the
-newer password format.

=== modified file 'docs/configuration/drizzled.rst'
--- docs/configuration/drizzled.rst	2011-10-02 06:29:23 +0000
+++ docs/configuration/drizzled.rst	2011-10-23 05:45:09 +0000
@@ -1,54 +1,63 @@
 .. program:: drizzled
 
+.. _drizzled_configuration:
+
+drizzled Configuration
+======================
+
 .. _drizzled_options:
 
-drizzled Options
-================
+Options
+-------
 
 .. _drizzled_gneral_options:
 
 General Options
----------------
+^^^^^^^^^^^^^^^
+
+.. option:: --help, -?
+
+   Display this help and exit.
 
 .. option:: --help-extended
 
    Display this help and exit after initializing plugins.
 
-.. option:: --help, -?
-
-   Display this help and exit.
-
 .. _drizzled_config_file_options:
 
 Config File Options
--------------------
+^^^^^^^^^^^^^^^^^^^
+
+.. option:: --config-dir DIR
+
+   :Default: :file:`/etc/drizzle`
+   :Variable: 
+
+   Base location for config files.
+
+.. option:: --defaults-file FILE
+   
+   :Default:
+   :Variable: 
+
+   Configuration file to use.
 
 .. option:: --no-defaults
 
-   Configuration file defaults are not used if no-defaults is set
-
-.. option:: --defaults-file arg
-
-   Configuration file to use
-
-.. option:: --config-dir arg (=/etc/drizzle)
-
-   Base location for config files
+   :Default:
+   :Variable: 
+
+   Configuration file defaults are not used if no-defaults is set.
 
 .. _drizzled_plugin_options:
 
 Plugin Options
---------------
-
-.. option:: --plugin-dir arg
-
-   Directory for plugins
-
-.. option:: --pid-file arg
-
-   Pid file used by drizzled.
-
-.. option:: --plugin-add arg
+^^^^^^^^^^^^^^
+
+.. option:: --plugin-add LIST
+
+   :Default:
+   :Variable: 
 
    Optional comma separated list of plugins to load at startup in addition
    to the default list of plugins.
@@ -57,7 +66,25 @@
 
      --plugin_add=crc32,console,pbxt
 
-.. option:: --plugin-remove arg
+.. option:: --plugin-dir DIR
+
+   :Default:
+   :Variable: 
+
+   Directory for plugins.
+
+.. option:: --plugin-load LIST
+
+   :Default: See :ref:`default_plugins`
+   :Variable: 
+
+   Optional comma separated list of plugins to load at starup instead of 
+   the default plugin load list. This completely replaces the whole list.
+
+.. option:: --plugin-remove LIST
+
+   :Default:
+   :Variable: 
 
    Optional comma separated list of plugins to not load at startup.
    Effectively removes a plugin from the list of plugins to be loaded.
@@ -66,199 +93,247 @@
 
      --plugin_remove=syslog,md5
 
-.. option:: --plugin-load arg (=version, uuid_function, user_function, transaction_log, syslog, substr_functions, sleep, show_schema_proto, rot13, reverse_function, rand_function, multi_thread, md5, logging_stats, length, hex_functions, hello_world, filtered_replicator, errmsg_stderr, default_replicator, database_function, crc32, connection_id, compression, charlength, benchmark, ascii)
-
-   Optional comma separated list of plugins to load at starup instead of 
-   the default plugin load list. This completely replaces the whole list.
-
 .. _drizzled_kernel_options:
 
 Kernel Options
---------------
-
-.. option:: --auto-increment-increment arg (=1)
-  
+^^^^^^^^^^^^^^
+
+.. option:: --auto-increment-increment ARG
+
+   :Default: 1
+   :Variable: ``auto_increment_increment``
+
    Auto-increment columns are incremented by this
 
-.. option:: --auto-increment-offset arg (=1)
+.. option:: --auto-increment-offset ARG
+
+   :Default: 1
+   :Variable: ``auto_increment_offset``
 
    Offset added to Auto-increment columns.
    Used when auto-increment-increment != 1
 
-.. option:: --basedir, -b arg
+.. option:: --back-log ARG
+
+   :Default: 50
+   :Variable: ``back_log``
+
+   The number of outstanding connection requests Drizzle can have. This comes
+   into play when the main Drizzle thread gets very many connection requests in
+   a very short time.
+
+.. option:: --basedir, -b ARG
+
+   :Default:
+   :Variable: ``basedir``
 
    Path to installation directory.
    All paths are usually resolved relative to this.
 
-.. option:: --chroot, -r arg
+.. option:: --bulk-insert-buffer-size SIZE
+
+   :Default: 8388608
+   :Variable: ``bulk_insert_buffer_size``
+
+   Size of tree cache used in bulk insert optimization. Note that this is a
+   limit per thread!
+
+.. option:: --chroot, -r ARG
+
+   :Default:
+   :Variable: 
 
    Chroot drizzled daemon during startup.
 
-.. option:: --collation-server arg
+.. option:: --collation-server ARG
+
+   :Default:
+   :Variable: ``collation_server``
 
    Set the default collation.
 
-.. option:: --completion-type arg (=0)
-
-   Default completion type.
+.. option:: --completion-type ARG
+
+   :Default: 0
+   :Variable: ``completion_type``
+
+   Unknown.
 
 .. option:: --core-file
 
+   :Default:
+   :Variable: 
+
    Write core on errors.
 
-.. option:: --datadir arg
+.. option:: --datadir ARG
+
+   :Default:
+   :Variable: ``datadir``
 
    Path to the database root.
 
-.. option:: --default-storage-engine arg
+.. option:: --default-storage-engine ARG
+
+   :Default: InnoDB
+   :Variable: ``storage_engine``
 
    Set the default storage engine for tables.
 
-.. option:: --default-time-zone arg
+.. option:: --default-time-zone ARG
+
+   :Default:
+   :Variable: 
 
    Set the default time zone.
 
+.. option:: --disable-optimizer-prune
+
+   :Default:
+   :Variable: ``optimizer_prune_level``
+
+   Do not apply any heuristic(s) during query optimization to prune, thus
+   perform an exhaustive search from the optimizer search space.
+
+.. option:: --div-precision-increment ARG
+
+   :Default: 4
+   :Variable: ``div_precision_increment``
+  
+   Precision of the result of '/' operator will be increased on that value.
+
 .. We should really remove --exit-info as an option
-.. option:: --exit-info, -T arg
+.. option:: --exit-info, -T ARG
+
+   :Default:
+   :Variable: 
 
    Used for debugging;  Use at your own risk!
 
 .. option:: --gdb
 
-   Set up signals usable for debugging
-
-.. option:: --lc-time-name arg
+   :Default:
+   :Variable: 
+
+   Set up signals usable for debugging.
+
+.. option:: --group-concat-max-len ARG
+
+   :Default: 1024
+   :Variable: ``group_concat_max_len``
+
+   The maximum length of the result of function  group_concat.
+
+.. option:: --join-buffer-constraint ARG
+
+   :Default: 0
+   :Variable: 
+
+   A global constraint for join-buffer-size for all clients, cannot be set lower
+   than :option:`--join-buffer-size`.  Setting to 0 means unlimited.
+
+.. option:: --join-buffer-size SIZE
+
+   :Default: 131072
+   :Variable: ``join_buffer_size``
+
+   The size of the buffer that is used for full joins.
+
+.. option:: --lc-time-name ARG
+
+   :Default:
+   :Variable: ``lc_time_names``
 
    Set the language used for the month names and the days of the week.
 
-.. option:: --log-warnings, -W arg
+.. option:: --log-warnings, -W ARG
+
+   :Default:
+   :Variable: 
 
    Log some not critical warnings to the log file.
 
-.. Why is this a core argument?
-.. option:: --port-open-timeout arg (=0)
-
-   Maximum time in seconds to wait for the port to become free.
-   A value of 0 means not to wait.
-
-.. option:: --secure-file-priv arg
-
-   Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within
-   specified directory
-
-.. Why is this still here?
-.. option:: --server-id arg (=0)
-
-   Uniquely identifies the server instance in the community of replication
-   partners.
-
-.. option:: --skip-stack-trace
-
-   Don't print a stack trace on failure.
-
-.. option:: --symbolic-links, -s
-
-   Enable symbolic link support.
-
-.. option:: --timed-mutexes
-
-   Specify whether to time mutexes (only InnoDB mutexes are currently supported)
-
-.. option:: --tmpdir, -t arg
-
-   Path for temporary files.
-
-.. option:: --transaction-isolation arg
-
-   Default transaction isolation level.
-
-.. option:: --user, -u arg
-
-   Run drizzled daemon as user.
-  
-.. option:: --version, -V
-
-   Output version information and exit.
-
-.. option:: --back-log arg (=50)
-
-   The number of outstanding connection requests Drizzle can have. This comes
-   into play when the main Drizzle thread gets very many connection requests in
-   a very short time.
-
-.. option:: --bulk-insert-buffer-size arg (=8388608)
-  
-   Size of tree cache used in bulk insert optimization. Note that this is a
-   limit per thread!
-
-.. option:: --div-precision-increment arg (=4)
-  
-   Precision of the result of '/' operator will be increased on that value.
-
-.. option:: --group-concat-max-len arg (=1024)
-
-   The maximum length of the result of function  group_concat.
-
-.. option:: --join-buffer-size arg (=131072)
-
-   The size of the buffer that is used for full joins.
-
-.. option:: --join-buffer-constraint arg (=0)
-
-   A global constraint for join-buffer-size for all clients, cannot be set lower
-   than --join-buffer-size.  Setting to 0 means unlimited.
-
-.. Why is this a core arg?
-.. option:: --max-allowed-packet arg (=64M)
+.. Why is this a core ARG?
+.. option:: --max-allowed-packet SIZE
+
+   :Default: 64M
+   :Variable: ``max_allowed_packet``
 
    Max packetlength to send/receive from to server.
 
-.. option:: --max-connect-errors arg (=10)
+.. option:: --max-connect-errors ARG
+
+   :Default: 10
+   :Variable: 
 
    If there is more than this number of interrupted connections from a host 
    this host will be blocked from further connections.
 
-.. option:: --max-error-count arg (=64)
+.. option:: --max-error-count ARG
+
+   :Default: 64
+   :Variable: ``max_error_count``
 
    Max number of errors/warnings to store for a statement.
 
-.. option:: --max-heap-table-size arg (=16M)
+.. option:: --max-heap-table-size SIZE
+
+   :Default: 16M
+   :Variable: ``max_heap_table_size``
 
    Don't allow creation of heap tables bigger than this.
 
-.. option:: --max-join-size arg (=2147483647)
+.. option:: --max-join-size SIZE
+
+   :Default: 2147483647
+   :Variable: ``max_join_size``
 
    Joins that are probably going to read more than max_join_size records return 
    an error.
 
-.. option:: --max-length-for-sort-data arg (=1024)
+.. option:: --max-length-for-sort-data SIZE
+
+   :Default: 1024
+   :Variable: ``max_length_for_sort_data``
 
    Max number of bytes in sorted records.
-  
-.. option:: --max-seeks-for-key arg (=18446744073709551615)
-
-   Limit assumed max number of seeks when looking up rows based on a key
-
-.. option:: --max-sort-length arg (=1024)
+
+.. option:: --max-seeks-for-key ARG
+
+   :Default: -1
+   :Variable: ``max_seeks_for_key``
+
+   Limit assumed max number of seeks when looking up rows based on a key.
+   Set to -1 to disable.
+
+.. option:: --max-sort-length SIZE
+
+   :Default: 1024
+   :Variable: ``max_sort_length``
 
    The number of bytes to use when sorting BLOB or TEXT values (only the first 
    max_sort_length bytes of each value are used; the rest are ignored).
 
-.. option:: --max-write-lock-count arg (=18446744073709551615)
+.. option:: --max-write-lock-count ARG
+
+   :Default: -1
+   :Variable: ``max_write_lock_count``
 
    After this many write locks, allow some read locks to run in between.
-
-.. option:: --min-examined-row-limit arg (=0)
+   Set to -1 to disable.
+
+.. option:: --min-examined-row-limit ARG
+
+   :Default: 0
+   :Variable: ``min_examined_row_limit``
 
    Don't log queries which examine less than min_examined_row_limit rows to
    file.
 
-.. option:: --disable-optimizer-prune
-
-   Do not apply any heuristic(s) during query optimization to prune, thus
-   perform an exhaustive search from the optimizer search space.
-
-.. option:: --optimizer-search-depth arg (=0)
+.. option:: --optimizer-search-depth ARG
+
+   :Default: 0
+   :Variable: ``optimizer_search_depth``
 
    Maximum depth of search performed by the query optimizer. Values larger than
    the number of relations in a query result in better query plans, but take
@@ -268,76 +343,846 @@
    MAX_TABLES+2, the optimizer will switch to the original find_best (used for
    testing/comparison).
 
-.. option:: --preload-buffer-size arg (=32768)
-
-   The size of the buffer that is allocated when preloading indexes
-
-.. option:: --query-alloc-block-size arg (=8192)
-
-   Allocation block size for query parsing and execution
-
-.. option:: --query-prealloc-size arg (=8192)
-
-   Persistent buffer for query parsing and execution
-
-.. option:: --range-alloc-block-size arg (=4096)
-
-   Allocation block size for storing ranges during optimization
-
-.. option:: --read-buffer-size arg (=131072)
+.. option:: --pid-file FILE
+   
+   :Default:
+   :Variable: ``pid_file``
+
+   PID file used by :program:`drizzled`.
+
+.. Why is this a core argument?
+.. option:: --port-open-timeout ARG
+
+   :Default: 0
+   :Variable: 
+
+   Maximum time in seconds to wait for the port to become free.
+   A value of 0 means not to wait.
+
+.. option:: --preload-buffer-size SIZE
+
+   :Default: 32768
+   :Variable: ``preload_buffer_size``
+
+   The size of the buffer that is allocated when preloading indexes.
+
+.. option:: --query-alloc-block-size SIZE
+
+   :Default: 8192
+   :Variable: ``query_alloc_block_size``
+
+   Allocation block size for query parsing and execution.
+
+.. option:: --query-prealloc-size SIZE
+
+   :Default: 8192
+   :Variable: ``query_prealloc_size``
+
+   Persistent buffer for query parsing and execution.
+
+.. option:: --range-alloc-block-size SIZE
+
+   :Default: 4096
+   :Variable: ``range_alloc_block_size``
+
+   Allocation block size for storing ranges during optimization.
+
+.. option:: --read-buffer-constraint ARG
+
+   :Default: 0
+   :Variable: 
+
+   A global constraint for read-buffer-size for all clients, cannot be set lower
+   than --read-buffer-size.  Setting to 0 means unlimited.
+
+.. option:: --read-buffer-size SIZE
+
+   :Default: 131072
+   :Variable: ``read_buffer_size``
 
    Each thread that does a sequential scan allocates a buffer of this size for
    each table it scans. If you do many sequential scans, you may want to
    increase this value.  Note that this only affect MyISAM.
 
-.. option:: --read-buffer-constraint arg (=0)
-
-   A global constraint for read-buffer-size for all clients, cannot be set lower
-   than --read-buffer-size.  Setting to 0 means unlimited.
-
-.. option:: --read-rnd-buffer-size arg (=262144)
+.. option:: --read-rnd-buffer-size SIZE
+
+   :Default: 262144
+   :Variable: ``read_rnd_buffer_size``
 
    When reading rows in sorted order after a sort, the rows are read through
    this buffer to avoid a disk seeks. If not set, then it's set to the value of
    record_buffer.
 
-.. option:: --read-rnd-constraint arg (=0)
+.. option:: --read-rnd-constraint ARG
+
+   :Default: 0
+   :Variable: 
 
    A global constraint for read-rnd-buffer-size for all clients, cannot be set
    lower than --read-rnd-buffer-size.  Setting to 0 means unlimited.
 
-.. option:: --scheduler arg (=multi-thread)
+.. option:: --replicate-query
+
+   :Default:
+   :Variable: ``replicate_query``
+   
+   Include the SQL query in replicated protobuf messages.
+
+.. option:: --scheduler ARG
+
+   :Default: multi-thread
+   :Variable: ``scheduler``
 
    Select scheduler to be used.
 
-.. option:: --sort-buffer-size arg (=2097144)
-
-   Each thread that needs to do a sort allocates a buffer of this size.
-
-.. option:: --sort-buffer-constraint arg (=0)
+.. option:: --secure-file-priv ARG
+
+   :Default:
+   :Variable: ``secure_file_priv``
+
+   Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within
+   specified directory.
+
+.. Why is this still here?
+.. option:: --server-id ARG
+
+   :Default: 0
+   :Variable: ``server_id``
+
+   Uniquely identifies the server instance in the community of replication
+   partners.
+
+.. option:: --skip-stack-trace
+
+   :Default:
+   :Variable: 
+
+   Don't print a stack trace on failure.
+
+.. option:: --sort-buffer-constraint ARG
+
+   :Default: 0
+   :Variable: 
 
    A global constraint for sort-buffer-size for all clients, cannot be set lower
    than --sort-buffer-size.  Setting to 0 means unlimited.
 
-.. option:: --table-definition-cache arg (=128)
+.. option:: --sort-buffer-size SIZE
+   
+   :Default: 2097144
+   :Variable: ``sort_buffer_size``
+
+   Each thread that needs to do a sort allocates a buffer of this size.
+
+.. option:: --symbolic-links, -s
+
+   :Default:
+   :Variable: 
+
+   Enable symbolic link support.
+
+.. option:: --table-definition-cache ARG
+
+   :Default: 128
+   :Variable: ``table_definition_cache``
 
    The number of cached table definitions.
 
-.. option:: --table-open-cache arg (=1024)
-
-   The number of cached open tables.
-
-.. option:: --table-lock-wait-timeout arg (=50)
+.. option:: --table-lock-wait-timeout ARG
+
+   :Default: 50
+   :Variable: ``table_lock_wait_timeout``
 
    Timeout in seconds to wait for a table level lock before returning an error.
    Used only if the connection has active cursors.
 
-.. option:: --thread-stack arg (=0)
+.. option:: --table-open-cache ARG
+
+   :Default: 1024
+   :Variable: ``table_open_cache``
+
+   The number of cached open tables.
+
+.. option:: --thread-stack ARG
+
+   :Default: 0
+   :Variable: ``thread_stack``
 
    The stack size for each thread. 0 means use OS default.
 
-.. option:: --tmp-table-size arg (=16M)
+.. option:: --timed-mutexes
+
+   :Default:
+   :Variable: ``timed_mutexes``
+
+   Specify whether to time mutexes (only InnoDB mutexes are currently supported).
+
+.. option:: --tmp-table-size SIZE
+
+   :Default: 16M
+   :Variable: ``tmp_table_size``
 
    If an internal in-memory temporary table exceeds this size, Drizzle will
    automatically convert it to an on-disk MyISAM table.
 
+.. option:: --tmpdir, -t DIR
+
+   :Default:
+   :Variable: ``tmpdir``
+
+   Path for temporary files.
+
+.. option:: --transaction-isolation ARG
+
+   :Default: REPEATABLE-READ
+   :Variable: ``tx_isolation``
+
+   Default transaction isolation level.
+
+.. option:: --transaction-message-threshold
+
+   :Default: 1048576
+   :Variable: ``transaction_message_threshold``
+
+   Max message size written to transaction log, valid values 131072 - 1048576 bytes.
+
+.. option:: --user, -u ARG
+
+   :Default:
+   :Variable: 
+
+   Run drizzled daemon as user.
+  
+.. option:: --version, -V
+
+   :Default:
+   :Variable: ``version``
+
+   Output version information and exit.
+
+.. _drizzled_variables:
+
+Variables
+---------
+
+.. _drizzled_auto_increment_increment:
+
+* ``auto_increment_increment``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auto-increment-increment`
+
+.. _drizzled_auto_increment_offset:
+
+* ``auto_increment_offset``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--auto-increment-offset`
+
+.. _drizzled_autocommit:
+
+* ``autocommit``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   If statements are auto-committed.
+
+.. _drizzled_back_log:
+
+* ``back_log``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--back-log`
+
+.. _drizzled_basedir:
+
+* ``basedir``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--basedir`
+
+.. _drizzled_bulk_insert_buffer_size:
+
+* ``bulk_insert_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--bulk-insert-buffer-size`
+
+.. _drizzled_collation_server:
+
+* ``collation_server``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--collation-server`
+
+.. _drizzled_completion_type:
+
+* ``completion_type``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--completion-type`
+
+.. _drizzled_datadir:
+
+* ``datadir``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--datadir`
+
+.. _drizzled_div_precision_increment:
+
+* ``div_precision_increment``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--div-precision-increment`
+
+.. _drizzled_error_count:
+
+* ``error_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Error count.
+
+.. _drizzled_foreign_key_checks:
+
+* ``foreign_key_checks``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   If foreign key checks are enabled.
+
+.. _drizzled_group_concat_max_len:
+
+* ``group_concat_max_len``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--group-concat-max-len`
+
+.. _drizzled_hostname:
+
+* ``hostname``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Hostname of the server.
+
+.. _drizzled_identity:
+
+* ``identity``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_join_buffer_size:
+
+* ``join_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--join-buffer-size`
+
+.. _drizzled_last_insert_id:
+
+* ``last_insert_id``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Last auto-increment insert ID value.
+
+.. _drizzled_lc_time_names:
+
+* ``lc_time_names``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_max_allowed_packet:
+
+* ``max_allowed_packet``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-allowed-packet`
+
+.. _drizzled_max_error_count:
+
+* ``max_error_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-error-count`
+
+.. _drizzled_max_heap_table_size:
+
+* ``max_heap_table_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-heap-table-size`
+
+.. _drizzled_max_join_size:
+
+* ``max_join_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-join-size`
+
+.. _drizzled_max_length_for_sort_data:
+
+* ``max_length_for_sort_data``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-length-for-sort-data`
+
+.. _drizzled_max_seeks_for_key:
+
+* ``max_seeks_for_key``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-seeks-for-key`
+
+.. _drizzled_max_sort_length:
+
+* ``max_sort_length``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-sort-length`
+
+.. _drizzled_max_write_lock_count:
+
+* ``max_write_lock_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--max-write-lock-count`
+
+.. _drizzled_min_examined_row_limit:
+
+* ``min_examined_row_limit``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--min-examined-row-limit`
+
+.. _drizzled_optimizer_prune_level:
+
+* ``optimizer_prune_level``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--disable-optimizer-prune`
+
+   Optimizer prune level.
+
+.. _drizzled_optimizer_search_depth:
+
+* ``optimizer_search_depth``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--optimizer-search-depth`
+
+.. _drizzled_pid_file:
+
+* ``pid_file``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--pid-file`
+
+.. _drizzled_plugin_dir:
+
+* ``plugin_dir``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--plugin-dir`
+
+.. _drizzled_preload_buffer_size:
+
+* ``preload_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--preload-buffer-size`
+
+.. _drizzled_pseudo_thread_id:
+
+* ``pseudo_thread_id``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_query_alloc_block_size:
+
+* ``query_alloc_block_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--query-alloc-block-size`
+
+.. _drizzled_query_prealloc_size:
+
+* ``query_prealloc_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--query-prealloc-size`
+
+.. _drizzled_range_alloc_block_size:
+
+* ``range_alloc_block_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--range-alloc-block-size`
+
+.. _drizzled_read_buffer_size:
+
+* ``read_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--read-buffer-size`
+
+.. _drizzled_read_rnd_buffer_size:
+
+* ``read_rnd_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--read-rnd-buffer-size`
+
+.. _drizzled_replicate_query:
+
+* ``replicate_query``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--replicate-query`
+
+.. _drizzled_scheduler:
+
+* ``scheduler``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--scheduler`
+
+.. _drizzled_secure_file_priv:
+
+* ``secure_file_priv``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--secure-file-priv`
+
+.. _drizzled_server_id:
+
+* ``server_id``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--server-id`
+
+.. _drizzled_server_uuid:
+
+* ``server_uuid``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Server UUID.
+
+.. _drizzled_sort_buffer_size:
+
+* ``sort_buffer_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--sort-buffer-size`
+
+.. _drizzled_sql_big_selects:
+
+* ``sql_big_selects``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_sql_buffer_result:
+
+* ``sql_buffer_result``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_sql_notes:
+
+* ``sql_notes``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_sql_select_limit:
+
+* ``sql_select_limit``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_sql_warnings:
+
+* ``sql_warnings``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.
+
+.. _drizzled_storage_engine:
+
+* ``storage_engine``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--default-storage-engine`
+
+.. _drizzled_table_definition_cache:
+
+* ``table_definition_cache``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--table-definition-cache`
+
+.. _drizzled_table_lock_wait_timeout:
+
+* ``table_lock_wait_timeout``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--table-lock-wait-timeout`
+
+.. _drizzled_table_open_cache:
+
+* ``table_open_cache``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--table-open-cache`
+
+.. _drizzled_thread_stack:
+
+* ``thread_stack``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--thread-stack`
+
+.. _drizzled_timed_mutexes:
+
+* ``timed_mutexes``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--timed-mutexes`
+
+.. _drizzled_timestamp:
+
+* ``timestamp``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Current UNIX timestamp.
+
+.. _drizzled_tmp_table_size:
+
+* ``tmp_table_size``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--tmp-table-size`
+
+.. _drizzled_tmpdir:
+
+* ``tmpdir``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--tmpdir`
+
+.. _drizzled_transaction_message_threshold:
+
+* ``transaction_message_threshold``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transaction-message-threshold`
+
+.. _drizzled_tx_isolation:
+
+* ``tx_isolation``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--transactions-isolation`
+
+.. _drizzled_unique_checks:
+
+* ``unique_checks``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Check UNIQUE indexes for uniqueness.
+
+.. _drizzled_vc_branch:
+
+* ``vc_branch``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version control (Bazaar) branch.
+
+.. _drizzled_vc_release_id:
+
+* ``vc_release_id``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version control (Bazaar) release id.
+
+.. _drizzled_vc_revid:
+
+* ``vc_revid``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version control (Bazaar) revision id.
+
+.. _drizzled_vc_revno:
+
+* ``vc_revno``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version control (Bazaar) revision number.
+
+.. _drizzled_version:
+
+* ``version``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: :option:`--version`
+
+   Drizzle version.
+
+.. _drizzled_version_comment:
+
+* ``version_comment``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version comment.
+
+.. _drizzled_version_compile_machine:
+
+* ``version_compile_machine``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version compile for machine type.
+
+.. _drizzled_version_compile_os:
+
+* ``version_compile_os``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version compile for OS.
+
+.. _drizzled_version_compile_vendor:
+
+* ``version_compile_vendor``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Version compile for OS vendor.
+
+.. _drizzled_warning_count:
+
+* ``warning_count``
+
+   :Scope: Global
+   :Dynamic: No
+   :Option: 
+
+   Unknown.

=== added file 'docs/configuration/index.rst'
--- docs/configuration/index.rst	1970-01-01 00:00:00 +0000
+++ docs/configuration/index.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,17 @@
+
+.. _configuring_drizzle:
+
+Configuring Drizzle
+===================
+
+Drizzle is configured by familiar methods: command line options and runtime
+variables.  Options are specified when starting :program:`drizzled`, the
+Drizzle server daemon, and variables are queried and set once Drizzle is
+running, usually with the :ref:`drizzle_command_line_client`.
+
+.. toctree::
+   :maxdepth: 2
+
+   options
+   variables
+   values

=== modified file 'docs/configuration/options.rst'
--- docs/configuration/options.rst	2011-10-02 06:29:23 +0000
+++ docs/configuration/options.rst	2011-10-23 05:45:09 +0000
@@ -14,18 +14,44 @@
 
 Values from :ref:`command_line_options` have the highest precedence;
 they override values from :ref:`config_files` which override the defaul
-values.  However, the :ref:`drizzled_config_file_options` are special:
-they are read first and they can only be specified on the command line.
-
-The default values alone are sufficient to start :program:`drizzled`,
+values.  The default values alone are sufficient to start :program:`drizzled`,
 but since they provide only the most basic configuration, you will certainly
 want to specify other options.
 
+To see which options are available, run ``drizzled --help``.  You can also
+see which options a plugin provides by running
+``drizzled --plugin-add PLUGIN --help`` where ``PLUGIN`` is the name of any
+plugin.  For example:
+
+.. code-block:: bash
+
+   $ drizzled --plugin-add query_log --help
+   sbin/drizzled  Ver 2011.08.25.2411 for pc-linux-gnu on i686 (Source distribution (trunk))
+   Copyright (C) 2010-2011 Drizzle Developers, Copyright (C) 2008 Sun Microsystems
+   This software comes with ABSOLUTELY NO WARRANTY. This is free software,
+   and you are welcome to modify and redistribute it under the GPL license
+   
+   ...
+
+   Options used by query_log:
+     --query-log.file-enabled                      Enable query logging to file
+     --query-log.file arg (=drizzled-queries.log)  Query log file
+     --query-log.threshold-execution-time arg (=0) Threshold for logging slow 
+                                                   queries, in microseconds
+
+Options listed by ``--help`` can be used as :ref:`command_line_options`.
+To use them in :ref:`config_files`, strip the leading ``--``.
+
+.. note:: Since Drizzle uses many plugins, the available options vary depending on which plugins are loaded.  If you cannnot find a certain option, ensure that the plugin which provides the option is loaded.
+
 .. _setting_options:
 
 Setting Options
 ---------------
 
+Options are read from one or more of the following sources.  Each source
+is optional.
+
 .. _config_files:
 
 Config Files
@@ -108,9 +134,10 @@
 Multiple Config Files
 ---------------------
 
-:option:`--defaults-file` specifies one config file, but :option:`--config-dir`
-specifies a directory which can contain multiple config files.  If a file
-named :file:`drizzled.cnf` exists in the config dir, it is read first.
+The command line option :option:`--defaults-file` specifies one config file,
+but :option:`--config-dir` specifies a directory which can contain multiple
+config files.  If a file named :file:`drizzled.cnf` exists in the config dir,
+it is read first.
 If the config dir contains a directory called :file:`conf.d`, then *every*
 file in that directory is read as a config file.  (Even hidden files are read,
 including hidden temp files created by your editor while editing config files
@@ -160,32 +187,3 @@
 so specifying them disables them.  For example, ``--innodb.disable-checksums``
 disables InnoDB checkum validation because it is enabled by default.
 
-.. _available_options:
-
-Available Options
------------------
-
-To see which options are available, run ``drizzled --help``.  You can also
-see which options a plugin provides by running
-``drizzled --plugin-add PLUGIN --help`` where ``PLUGIN`` is the name of any
-plugin.  For example:
-
-.. code-block:: bash
-
-   $ drizzled --plugin-add query_log --help
-   sbin/drizzled  Ver 2011.08.25.2411 for pc-linux-gnu on i686 (Source distribution (trunk))
-   Copyright (C) 2010-2011 Drizzle Developers, Copyright (C) 2008 Sun Microsystems
-   This software comes with ABSOLUTELY NO WARRANTY. This is free software,
-   and you are welcome to modify and redistribute it under the GPL license
-   
-   ...
-
-   Options used by query_log:
-     --query-log.file-enabled                      Enable query logging to file
-     --query-log.file arg (=drizzled-queries.log)  Query log file
-     --query-log.threshold-execution-time arg (=0) Threshold for logging slow 
-                                                   queries, in microseconds
-
-Options listed by ``--help`` can be used as :ref:`command_line_options`.
-To use them in :ref:`config_files`, strip the leading ``--``.
-

=== modified file 'docs/configuration/values.rst'
--- docs/configuration/values.rst	2011-10-02 06:29:23 +0000
+++ docs/configuration/values.rst	2011-10-23 05:45:09 +0000
@@ -37,7 +37,7 @@
 
 When :ref:`setting a variable <setting_variables>`, boolean values are
 one of the various true and false values listed for the
-:doc:`/boolean_data_type`.  When setting a :ref:`boolean_options`,
+:doc:`/boolean_data_type`.  When setting :ref:`boolean_options`,
 no value is need or allowed.
 
 Size

=== modified file 'docs/configuration/variables.rst'
--- docs/configuration/variables.rst	2011-10-02 06:29:23 +0000
+++ docs/configuration/variables.rst	2011-10-23 05:45:09 +0000
@@ -10,31 +10,77 @@
 whereas :ref:`configuration_options` configure Drizzle at startup and cannot
 be changed without restarting Drizzle.
 
-Each variable has three aspects:
-
-1. Corresponding option
-2. Dynamic or static
-3. Global or session
-
-Most variables have a corresponding option which
-initialize the variable.  For example, :option:`--datadir` corresponds to
-and initializes the variable ``datadir``.  The variable name is derived
-from the option name by stripping the option's leading ``--`` and changing
-all ``-`` (hyphens) and ``.`` (periods) to ``_`` (underscores).
-
-Dynamic variables can be changed at runtime and the change takes affect
-immediately. Most variables, however, are static which means that they
-only reflect the value of their corresponding option.  To change a static
+To see which variables are avaiable, execute the following:
+
+.. code-block:: mysql
+
+   drizzle> SELECT * FROM DATA_DICTIONARY.GLOBAL_VARIABLES;
+   +--------------------------------------------+--------------------+
+   | Variable_name                              | Value              |
+   +--------------------------------------------+--------------------+
+   | auto_increment_increment                   | 1                  | 
+   | auto_increment_offset                      | 1                  | 
+   | autocommit                                 | ON                 | 
+   | back_log                                   | 128                | 
+   | basedir                                    | /opt/drizzle       |
+   | bulk_insert_buffer_size                    | 8388608            | 
+   | collation_server                           | utf8_general_ci    | 
+   | completion_type                            | 0                  | 
+   | datadir                                    | /opt/drizzle/data  |
+   | div_precision_increment                    | 4                  | 
+   | drizzle_protocol_bind_address              | localhost          | 
+   | drizzle_protocol_buffer_length             | 16384              | 
+   | drizzle_protocol_connect_timeout           | 10                 | 
+   | drizzle_protocol_max_connections           | 1000               | 
+   | drizzle_protocol_port                      | 290132299          | 
+   | drizzle_protocol_read_timeout              | 30                 | 
+   | drizzle_protocol_retry_count               | 10                 | 
+   | drizzle_protocol_write_timeout             | 60                 | 
+   | error_count                                | 0                  | 
+   | foreign_key_checks                         | ON                 | 
+   ...
+
+The ``DATA_DICTIONARY.GLOBAL_VARIABLES`` and
+``DATA_DICTIONARY.SESION_VARIABLES`` views only list the available variables
+and their current values, but internally each variable has four attributes
+which affect how, if, and when it can be set:
+
+#. Creator
+#. Option
+#. Dynamic
+#. Scope
+
+Variable are created either by the Drizzle kernel or by a plugin.
+Varaibles created by a plugin are prefixed with the plugin's name.
+For example, ``drizzle_protocol_port`` is created by the
+:doc:`/plugins/drizzle_protocol/index` plugin.  Else, the variable
+is created by the Drizzle kernel.
+
+Most variables have a corresponding
+:ref:`command line option <command_line_options>` which
+initializes the variable.  For example, :option:`--drizzle-protocol.port`
+initializes ``drizzle_protocol_port``.  Command line options are
+converted to variable names by stripping
+the option's leading ``--`` and changing all ``-`` (hyphens) and ``.`` 
+(periods) to ``_`` (underscores).  Variables without corresponding
+command line options are are usually switches (to enable or disable
+some feature) or counters (like ``error_count``), and these variables can
+only be accessed or changed once Drizzle is running.
+
+Dynamic variables can be changed at runtime, and the new value takes
+affect immediately.  Documentation for each variables indicates if it is
+dynamic or not.  Most variables, however, are static which means that
+they only reflect the value of their corresponding option.  To change a static
 variable, you must change its corresponding option, then restart Drizzle.
 Certain variables are static and do not have a corresponding option because
 they are purely informational, like ``version`` and ``version_comment``.
 
-All variables are global, but each connection receives a copy of all global
-variables called session variables.  A connection can change dynamic session
-variables without affecting the rest of the server or other sessions, or it
-can potentially change dynamic global variables which affects all connections.
-Changes to dynamic session variables are lost when the connection is closed,
-and changes to dynamic global variables remain in affect until changed again.
+A variable's scope is either global, session, or both (global and session).
+Global variables apply to all connections (each connection is a session).
+Session variables apply to each connection and changes to a session in one
+connection do not change or affect the same variable in another connection.
+Changes to session variables are lost when the connection closes, but
+changes to global variables remain in affect until changed again.
 
 .. note:: Configuration variables and :ref:`user_defined_variables` are different.  :ref:`user_defined_variables` do not affect the configuration of Drizzle, and they are always dynamic, session variables.
 
@@ -74,22 +120,23 @@
 ------------------
 
 The ``DATA_DICTIONARY.GLOBAL_VARIABLES`` and
-``DATA_DICTIONARY.SESSION_VARIABLES`` are views for querying the
-global and session variables respectively.  For example:
+``DATA_DICTIONARY.SESSION_VARIABLES`` are views for querying 
+global and session variables respectively.  For example, to see all
+variables for the :doc:`/plugins/syslog/index` plugin:
 
 .. code-block:: mysql
 
-   drizzle> SELECT * FROM DATA_DICTIONARY.GLOBAL_VARIABLES WHERE VARIABLE_NAME LIKE 'max%';
-   +--------------------------+----------------+
-   | VARIABLE_NAME            | VARIABLE_VALUE |
-   +--------------------------+----------------+
-   | max_allowed_packet       | 67108864       | 
-   | max_error_count          | 64             | 
-   | max_heap_table_size      | 16777216       | 
-   | max_join_size            | 2147483647     | 
-   | max_length_for_sort_data | 1024           | 
-   | max_seeks_for_key        | 4294967295     | 
-   | max_sort_length          | 1024           | 
-   | max_write_lock_count     | -1             | 
-   +--------------------------+----------------+
+   drizzle> SELECT * FROM DATA_DICTIONARY.GLOBAL_VARIABLES WHERE VARIABLE_NAME LIKE 'syslog_%';
+   +----------------------------------------+----------------+
+   | VARIABLE_NAME                          | VARIABLE_VALUE |
+   +----------------------------------------+----------------+
+   | syslog_errmsg_enable                   | OFF            | 
+   | syslog_errmsg_priority                 | warning        | 
+   | syslog_facility                        | local0         | 
+   | syslog_logging_enable                  | OFF            | 
+   | syslog_logging_priority                | warning        | 
+   | syslog_logging_threshold_big_examined  | 0              | 
+   | syslog_logging_threshold_big_resultset | 0              | 
+   | syslog_logging_threshold_slow          | 0              | 
+   +----------------------------------------+----------------+
 

=== modified file 'docs/contributing/code.rst'
--- docs/contributing/code.rst	2011-03-08 03:47:42 +0000
+++ docs/contributing/code.rst	2011-10-23 05:45:09 +0000
@@ -1,8 +1,13 @@
-.. _code-label:
+.. _contributing_code:
 
 Contributing Code
 =================
 
+We recommend that anyone new to Drizzle who wants to learn the code shoult
+see the
+`Low hanging fruit <https://bugs.launchpad.net/drizzle/+bugs?field.tag=low-hanging-fruit>`_
+list of bugs on Launchpad for possible tasks to take on.
+
 SSH Keys
 --------
 
@@ -78,11 +83,22 @@
 Test Cases
 ----------
 
+.. program:: test-run
+
 Where possible, SQL test cases should be created for your code.  Our test cases
 for bug fixes should be in the ``tests/suite/regression`` directory.  For more
 information about creating test cases please see the :ref:`test run <test-run-label>`
 section of our documentation.
 
+If writing a plugin, the other plugins in trunk have many examples of test cases.
+
+You should attempt to test your code on multiple platforms before publishing
+it or proposing it for merging.  Your tests must pass on all
+:ref:`supported_platforms` and be idempotent (pass when ran with
+:option:`--repeat-test` 2).  You can test on other platforms by using
+`VirtualBox <https://www.virtualbox.org/>`_ or another virtualization
+server, or by requesting access to the `Drizzle Jenkins server <http://jenkins.drizzle.org/>`_.
+
 Pushing Work
 ------------
 
@@ -94,18 +110,20 @@
    bzr push lp:~username/drizzle/trunk-bug-NNNNNN
 
 This will create the branch on Launchpad which you will be able to see on the
-`code page <https://code.launchpad.net/drizzle>`_.  If you make some more commits you simply need to do just ``bzr push`` to get those revisions on Launchpad
-too.
+`code page <https://code.launchpad.net/drizzle>`_.  If you commit more changes
+to your branch, just ``bzr push`` to publish the new changes.
 
 Merge Proposals
 ---------------
 
-Once your work is done and ready for review you can go to the
-`code page <https://code.launchpad.net/drizzle>`_, and then click on your branch.
+Once your work is done and ready for review, go to
+`code page <https://code.launchpad.net/drizzle>`_, then click on your branch.
 You will see a link labeled *Propose for merging*.
 
 In this screen simply fill in what this branch does and click the
-*Propose Merge* button.  Someone will review the branch, usually within a day or
-two. If approved, it will go though our rigourous testing process, which can
+*Propose Merge* button.  Members of the
+`Drizzle merge team <https://launchpad.net/~drizzle-merge>`_
+will review the branch, usually within a few days.
+If approved, it will go though our rigourous testing process, which can
 take several hours.  If it needs more work, feedback will always be given to
 explain why.

=== modified file 'docs/contributing/documentation.rst'
--- docs/contributing/documentation.rst	2011-03-08 03:47:42 +0000
+++ docs/contributing/documentation.rst	2011-10-23 05:45:09 +0000
@@ -241,5 +241,5 @@
 ------------------------
 
 Documentation needs to be committed and merged in exactly the same way as
-regular development files.  For more information on this please see the
-:ref:`contributing code <code-label>` page.
+regular development files.  For more information see
+:ref:`contributing_code`.

=== added file 'docs/contributing/getting_started.rst'
--- docs/contributing/getting_started.rst	1970-01-01 00:00:00 +0000
+++ docs/contributing/getting_started.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,30 @@
+Getting Started
+===============
+
+Drizzle values community contributions the same as core developer
+contributions.  All contributions, regardless of their author,
+undergo the same rigorous testing and approval process before being
+merged into the main code base.
+
+The `Drizzle project <https://launchpad.net/drizzle>`_ is hosted on
+`Launchpad <https://launchpad.net/>`_ which handles code revision control,
+bug tracking, mailing lists, and everything else needed to manage the
+project.  For most contributions, you will need a
+`Launchpad account <https://help.launchpad.net/YourAccount/NewAccount>`_.
+
+Bazaar
+------
+
+Launchpad uses `Bazaar (bzr) <http://bazaar.canonical.com/>`_ for revision
+control of the source repositories which includes code and documentation.
+If you are not comfortable with :program:`bzr`, begin by reading the
+`Bazaar documentation <http://doc.bazaar.canonical.com/>`_.  You can
+practice working with :program:`bzr` branches using your Launchpad account.
+
+Help
+----
+
+If you have questions, please ask on the
+`#drizzle <irc://irc.freenode.net/drizzle>`_
+`Freenode <http://freenode.net/>`_ IRC channel or on the
+`Drizzle Discuss <https://launchpad.net/~drizzle-discuss>`_ mailing list.

=== removed file 'docs/contributing/introduction.rst'
--- docs/contributing/introduction.rst	2011-03-08 03:47:42 +0000
+++ docs/contributing/introduction.rst	1970-01-01 00:00:00 +0000
@@ -1,40 +0,0 @@
-Introduction
-============
-
-Drizzle's development primarily happens on
-`Launchpad <https://launchpad.net/drizzle>`_ which handles code hosting, bugs tracking,
-mailing lists and everything else needed for project management.  You will need
-a `Launchpad account <https://help.launchpad.net/YourAccount/NewAccount>`_
-before making most kinds of contributions.
-
-One of Drizzle's aims is to have community contributions valued in the same way
-as core developer contributions, and to have all code undergo exactly the same
-approval and testing process no matter who it comes from (core developers or
-general community).
-
-There are many ways to contribute to Drizzle. For example, you can:
-
- * `File a bug <https://bugs.launchpad.net/drizzle/+filebug>`_
- * `Write translations <https://translations.launchpad.net/drizzle>`_
- * :ref:`Write documentation <documentation-label>`
- * :ref:`Write code <code-label>`
-
-We recommend anyone new to Drizzle who wants to learn the code see the
-`Low hanging fruit <https://bugs.launchpad.net/drizzle/+bugs?field.tag=low-hanging-fruit>`_
-list of bugs on Launchpad for possible tasks to take on.
-
-Bazaar
-------
-
-Launchpad uses `Bazaar <https://launchpad.net/bazaar>`_ for revision control of
-the source repositories and for documentation.  You will need this installed before contributing
-documentation or code.
-
-Finding Help
-------------
-
-If you have any questions please contact us at the
-`#drizzle <irc://irc.freenode.net/drizzle>`_
-`Freenode <http://freenode.net/>`_ IRC channel or on the
-`Drizzle Discuss <https://launchpad.net/~drizzle-discuss>`_ mailing list.
-

=== added file 'docs/contributing/more_ways.rst'
--- docs/contributing/more_ways.rst	1970-01-01 00:00:00 +0000
+++ docs/contributing/more_ways.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,21 @@
+More Ways to Contribute
+=======================
+
+Write Translations
+------------------
+
+Drizzle is multilingual and Launchpad provides an easy interface
+to help translate Drizzle into other languages:
+https://translations.launchpad.net/drizzle
+
+Advocate Drizzle
+----------------
+
+Please join the `Drizzle Advocacy mailing list <https://launchpad.net/~drizzle-advocacy>`_ and help promote and expand knowledge about Drizzle.
+
+Make a Donation
+---------------
+
+Drizzle is an Associated Project at the
+`Software in the Public Interest (SPI) <http://spi-inc.org/>`_.  You
+can make a financial donation to Drizzle through the SPI.

=== added file 'docs/help.rst'
--- docs/help.rst	1970-01-01 00:00:00 +0000
+++ docs/help.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,10 @@
+Help and Support
+================
+
+If you have any questions, the core developers and many community members
+are frequently avaiable on the
+`#drizzle <irc://irc.freenode.net/drizzle>`_
+`Freenode <http://freenode.net/>`_ IRC channel or on the
+`Drizzle Discuss <https://launchpad.net/~drizzle-discuss>`_ mailing list.
+
+A number of companies provide `commercial support <http://www.drizzle.org/content/support-and-services>`_ for Drizzle.

=== modified file 'docs/how_to_report_a_bug.rst'
--- docs/how_to_report_a_bug.rst	2010-11-30 00:28:02 +0000
+++ docs/how_to_report_a_bug.rst	2011-10-23 05:45:09 +0000
@@ -1,7 +1,8 @@
-===================
-How to report a bug
+How to Report a Bug
 ===================
 
 Drizzle bugs can be reported at https://bugs.launchpad.net/drizzle. On the right side of the page you will see the link to "Report a bug", alongside links to ask questions, submit code, etc. 
 
 If you're interested in helping to fix some of Drizzle's current bugs, the team  maintains a list of low hanging fruit bugs on Launchpad: https://bugs.edge.launchpad.net/drizzle/+bugs?field.tag=low-hanging-fruit
+
+.. seealso:: :ref:`contributing_code`

=== modified file 'docs/index.rst'
--- docs/index.rst	2011-10-02 06:29:23 +0000
+++ docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,6 @@
+.. _auth_all@:
+
+
 .. Drizzle documentation master file, created by
    sphinx-quickstart on Fri Aug 27 08:33:41 2010.
    You can adapt this file completely to your liking, but it should at least
@@ -23,7 +26,6 @@
  * Simple design for ease of use and administration
  * Reliable, ACID transactional
 
-
 Introduction
 ------------
 .. toctree::
@@ -34,27 +36,55 @@
    what_is_drizzle
    brief_history_of_drizzle
    how_to_report_a_bug
+   help
    versioning
    mysql_differences
 
-Compiling and Installing
-------------------------
+Contributing
+------------
+.. toctree::
+   :maxdepth: 2
+
+   contributing/getting_started
+   contributing/code
+   contributing/documentation
+   contributing/more_ways
+
+Installing
+----------
 .. toctree::
    :maxdepth: 2
 
    installing/requirements
-   installing/from_source
    installing/ubuntu
    installing/redhat
-
-Contributing
-------------
-.. toctree::
-   :maxdepth: 2
-
-   contributing/introduction
-   contributing/code
-   contributing/documentation
+   installing/from_source
+
+Configuration
+-------------
+.. toctree::
+   :maxdepth: 2
+
+   configuration/index
+   configuration/drizzled
+
+Administration
+--------------
+.. toctree::
+   :maxdepth: 2
+
+   administration/drizzled
+   administration/authentication
+   administration/authorization
+   administration/plugins
+   administration/storage_engines
+
+Replication
+-----------
+.. toctree::
+   :maxdepth: 2
+
+   replication/drizzle
 
 SQL Language
 ------------
@@ -76,40 +106,6 @@
    administrative
    resources/index
 
-Replication
------------
-.. toctree::
-   :maxdepth: 2
-
-   replication
-
-Configuration
--------------
-.. toctree::
-   :maxdepth: 2
-
-   configuration/options
-   configuration/variables
-   configuration/values
-   configuration/drizzled
-
-Administration
---------------
-.. toctree::
-   :maxdepth: 2
-
-   administration/authentication
-   administration/authorization
-   administration/storage_engines
-
-
-Plugins
--------
-.. toctree::
-   :maxdepth: 2
-
-   plugins/list
-
 Clients
 -------
 .. toctree::
@@ -117,7 +113,21 @@
 
    clients/drizzle.rst
    clients/drizzledump.rst
-   clients/errors.rst
+
+Plugins
+-------
+.. toctree::
+   :maxdepth: 2
+
+   plugins/list
+   
+Release Notes
+-------------
+
+.. toctree::
+   :maxdepth: 2
+
+   release_notes/drizzle-7.0
 
 libdrizzle
 ----------

=== modified file 'docs/installing/from_source.rst'
--- docs/installing/from_source.rst	2011-03-17 16:33:45 +0000
+++ docs/installing/from_source.rst	2011-10-23 05:45:09 +0000
@@ -1,5 +1,5 @@
-Installing From Source
-======================
+Installing Drizzle from Source
+==============================
 
 * :ref:`dependencies`
 * :ref:`ubuntu-install`
@@ -61,7 +61,7 @@
 .. _ubuntu-install:
 
 Ubuntu Install Commands
--------------------------
+-----------------------
 
 The following commands work on Ubuntu to install the tools and libraries needed to build Drizzle:
 
@@ -75,7 +75,7 @@
 .. _debian-install:
 
 Debian Install Commands
--------------------------
+-----------------------
 
 Since apt-repository isn't in Debian, you can instead add the Maverick PPA to /etc/apt/sources.list as follows:
 
@@ -111,7 +111,7 @@
 
 .. _obtain-source:
 
-Obtaining The Source
+Obtaining the Source
 --------------------
 The latest source release can always be found on our `LaunchPad site
 <https://launchpad.net/drizzle>`_. Alternatively, the bzr source from our stable
@@ -123,7 +123,7 @@
 
 .. _compile-source:
 
-Compiling The Source
+Compiling the Source
 --------------------
 Compiling is done by performing the standard automake commands from the top level directory inside the source:
 

=== modified file 'docs/installing/redhat.rst'
--- docs/installing/redhat.rst	2011-03-10 18:18:24 +0000
+++ docs/installing/redhat.rst	2011-10-23 05:45:09 +0000
@@ -1,5 +1,5 @@
-Installing in RedHat and Fedora
-================================
+Installing on RedHat and Fedora
+===============================
 
 Using RPMs
 ----------
@@ -73,7 +73,7 @@
 
    sudo yum install drizzle7-server drizzle7-client
 
-Compiling From Source
+Compiling from Source
 ---------------------
 To compile from source you will need to add the repositories described above, and then install the following packages:
 

=== modified file 'docs/installing/requirements.rst'
--- docs/installing/requirements.rst	2011-03-28 16:39:07 +0000
+++ docs/installing/requirements.rst	2011-10-23 05:45:09 +0000
@@ -1,6 +1,8 @@
 Requirements
 ============
 
+.. _supported_platforms:
+
 Supported Platforms
 -------------------
 When installing Drizzle we typically recommend either using the packages from
@@ -13,7 +15,7 @@
  * RedHat (or CentOS) 5 and 6
  * Debian Squeeze (6.0)
  * Ubuntu 10.04 and 10.10
- * Apple OSX 10.6.4
+ * Apple OS X 10.6.4
 
 We recommend using these platforms with Drizzle. Older platforms may have various
 unforseen difficulties when compiling and/or installing.  Drizzle is tested on

=== modified file 'docs/installing/ubuntu.rst'
--- docs/installing/ubuntu.rst	2011-03-08 03:47:42 +0000
+++ docs/installing/ubuntu.rst	2011-10-23 05:45:09 +0000
@@ -1,5 +1,5 @@
-Installing In Ubuntu
-====================
+Installing on Ubuntu
+=====================
 
 Using DEBs
 ----------

=== added directory 'docs/release_notes'
=== added file 'docs/release_notes/drizzle-7.0.rst'
--- docs/release_notes/drizzle-7.0.rst	1970-01-01 00:00:00 +0000
+++ docs/release_notes/drizzle-7.0.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,7 @@
+Drizzle 7.0
+===========
+
+:Released: 2011-03-15
+:Version: 2011.03.13
+:URL: http://blog.drizzle.org/2011/03/15/drizzle-2011-03-12-ga-tarball-has-been-released/
+

=== added directory 'docs/replication'
=== removed file 'docs/replication.rst'
--- docs/replication.rst	2011-03-08 19:04:58 +0000
+++ docs/replication.rst	1970-01-01 00:00:00 +0000
@@ -1,324 +0,0 @@
-*******************
-Drizzle Replication
-*******************
-
-Replication events are recorded using messages in the `Google Protocol Buffer
-<http://code.google.com/p/protobuf/>`_ (GPB) format. GPB messages can contain
-sub-messages. There is a single main "envelope" message, Transaction, that
-is passed to plugins that subscribe to the replication stream.
-
-Configuration Options
-#####################
-
-**transaction_message_threshold**
-
-    Controls the size, in bytes, of the Transaction messages. When a Transaction
-    message exceeds this size, a new Transaction message with the same
-    transaction ID will be created to continue the replication events.
-    See :ref:`bulk-operations` below.
-
-
-**replicate_query**
-
-    Controls whether the originating SQL query will be included within each
-    Statement message contained in the enclosing Transaction message. The
-    default global value is FALSE which will not include the query in the
-    messages. It can be controlled per session, as well. For example:
-
-    .. code-block:: mysql
-
-       drizzle> set @@replicate_query = 1;
-
-    The stored query should be used as a guide only, and never executed
-    on a slave to perform replication as this will lead to incorrect results.
-
-Message Definitions
-###################
-
-The GPB messages are defined in .proto files in the drizzled/message
-directory of the Drizzle source code. The primary definition file is
-transaction.proto. Messages defined in this file are related in the
-following ways::
-
-
-  ------------------------------------------------------------------
-  |                                                                |
-  | Transaction message                                            |
-  |                                                                |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | TransactionContext message                              |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | Statement message 1                                     |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | Statement message 2                                     |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  |                             ...                                |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | Statement message N                                     |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  ------------------------------------------------------------------
-
-with each Statement message looking like so::
-
-  ------------------------------------------------------------------
-  |                                                                |
-  | Statement message                                              |
-  |                                                                |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | Common information                                      |  |
-  |   |                                                         |  |
-  |   |  - Type of Statement (INSERT, DELETE, etc)              |  |
-  |   |  - Start Timestamp                                      |  |
-  |   |  - End Timestamp                                        |  |
-  |   |  - (OPTIONAL) Actual SQL query string                   |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | Statement subclass message 1 (see below)                |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  |                             ...                                |
-  |   -----------------------------------------------------------  |
-  |   |                                                         |  |
-  |   | Statement subclass message N (see below)                |  |
-  |   |                                                         |  |
-  |   -----------------------------------------------------------  |
-  ------------------------------------------------------------------
-
-The Transaction Message
-#######################
-
-The main "envelope" message which represents an atomic transaction
-which changed the state of a server is the Transaction message class.
-
-The Transaction message contains two pieces:
-
-#. A TransactionContext message containing information about the
-   transaction as a whole, such as the ID of the executing server,
-   the start and end timestamp of the transaction, segmenting
-   metadata and a unique identifier for the transaction.
-#. A vector of Statement messages representing the distinct SQL
-   statements which modified the state of the server.  The Statement
-   message is, itself, a generic envelope message containing a
-   sub-message which describes the specific data modification which
-   occurred on the server (such as, for instance, an INSERT statement).
-
-The Statement Message
-#####################
-
-The generic "envelope" message containing information common to each
-SQL statement executed against a server (such as a start and end timestamp
-and the type of the SQL statement) as well as a Statement subclass message
-describing the specific data modification event on the server.
-
-Each Statement message contains a type member which indicates how readers
-of the Statement should construct the inner Statement subclass representing
-a data change.
-
-Statements are recorded separately as sometimes individual statements
-have to be rolled back.
-
-
-.. _bulk-operations:
-
-How Bulk Operations Work
-########################
-
-Certain operations which change large volumes of data on a server
-present a specific set of problems for a transaction coordinator or
-replication service. If all operations must complete atomically on a
-publishing server before replicas are delivered the complete
-transactional unit:
-
-#. The publishing server could consume a large amount of memory
-   building an in-memory Transaction message containing all the
-   operations contained  in the entire transaction.
-#. A replica, or subscribing server, is wasting time waiting on the
-   eventual completion (commit) of the large transaction on the
-   publishing server. It could be applying pieces of the large
-   transaction in the meantime...
-
-In order to prevent the problems inherent in (1) and (2) above, Drizzle's
-replication system uses a mechanism which provides bulk change
-operations.
-
-A single transaction in the database can possibly be represented with
-multiple protobuf Transaction messages if the message grows too large.
-This can happen if you have a bulk transaction, or a single statement
-affecting a very large number of rows, or just a large transaction with
-many statements/changes.
-
-For the first two examples, it is likely that the Statement sub-message
-itself will get segmented, causing another Transaction message to be
-created to hold the rest of the Statement's row changes. In these cases,
-it is enough to look at the segment information stored in the Statement
-message (see example below).
-
-For the last example, the Statement sub-messages may or may not be
-segmented, but we could still need to split the individual Statements up into
-multiple Transaction messages to keep the Transaction message size from
-growing too large. In this case, the segment information in the Statement
-submessages is not helpful if the Statement isn't segmented. We need this
-information in the Transaction message itself.
-
-Segmenting a Single SQL Statement
-*********************************
-
-When a regular SQL statement modifies or inserts more rows than a
-certain threshold, Drizzle's replication services component will begin
-sending Transaction messages to replicas which contain a chunk
-(or "segment") of the data which has been changed on the publisher.
-
-When data is inserted, updated, or modified in the database, a
-header containing information about modified tables and fields is
-matched with one or more data segments which contain the actual
-values changed in the statement.
-
-It's easiest to understand this mechanism by following through a real-world
-scenario.
-
-Suppose the following table:
-
-.. code-block:: mysql
-
-  CREATE TABLE test.person
-  (
-    id INT NOT NULL AUTO_INCREMENT PRIMARY KEY
-  , first_name VARCHAR(50)
-  , last_name VARCHAR(50)
-  , is_active CHAR(1) NOT NULL DEFAULT 'Y'
-  );
-
-Also suppose that test.t1 contains 1 million records.
-
-Next, suppose a client issues the SQL statement:
-
-.. code-block:: mysql
-
-  UPDATE test.person SET is_active = 'N';
-
-It is clear that one million records could be updated by this statement
-(we say, "could be" since Drizzle does not actually update a record if
-the UPDATE would not change the existing record...).
-
-In order to prevent the publishing server from having to construct an
-enormous Transaction message, Drizzle's replication services component
-will do the following:
-
-#. Construct a Transaction message with a transaction context containing
-   information about the originating server, the transaction ID, and
-   timestamp information.
-#. Construct an UpdateHeader message with information about the tables
-   and fields involved in the UPDATE statement.  Push this UpdateHeader
-   message onto the Transaction message's statement vector.
-#. Construct an UpdateData message.  Set the *segment_id* member to 1.
-   Set the *end_segment* member to true.
-#. For every record updated in a storage engine, the ReplicationServices
-   component builds a new UpdateRecord message and appends this message
-   to the aforementioned UpdateData message's record vector.
-#. After a certain threshold of records is reached, the
-   ReplicationServices component sets the current UpdateData message's
-   *end_segment* member to false, and proceeds to send the Transaction
-   message to replicators.
-#. The ReplicationServices component then constructs a new Transaction
-   message and constructs a transaction context with the same
-   transaction ID and server information.
-#. A new UpdateData message is created.  The message's *segment_id* is
-   set to N+1 and as new records are updated, new UpdateRecord messages
-   are appended to the UpdateData message's record vector.
-#. While records are being updated, we repeat steps 5 through 7, with
-   only the final UpdateData message having its *end_segment* member set
-   to true.
-
-Segmenting a Transaction
-************************
-
-The Transaction protobuf message also contains *segment_id* member and a
-*end_segment* member. These values are also set appropriately when a
-Statement sub-message is segmented, as described above.
-
-These values are also set when a Transaction must be segmented along
-individual Statement boundaries (i.e., the Statement message itself
-is **not** segmented). In either case, it is enough to check the
-*end_segment* and *segment_id* values of the Transaction message
-to determine if this is a multi-message transaction.
-
-Handling ROLLBACKs
-##################
-
-Both transactions and individual statements may be rolled back.
-
-When a transaction is rolled back, one of two things happen depending
-on whether the transaction is made up of either a single Transaction
-message, or if it is made up of multiple Transaction messages (e.g, bulk
-load).
-
-* For a transaction encapsulated entirely within a single Transaction
-  message, the entire message is simply discarded and not sent through
-  the replication stream.
-* For a transaction which is made up of multiple messages, and at least
-  one message has already been sent through the replication stream, then
-  the Transaction message will contain a Statement message with type =
-  ROLLBACK. This signifies to rollback the entire transaction.
-
-A special Statement message type, ROLLBACK_STATEMENT, is used when
-we have a segmented Statement message (see above) and we need to tell the
-receiver to undo any changes made for this single statement, but not
-for the entire transaction. If the receiver cannot handle rolling back
-a single statement, then a message buffering strategy should be employed 
-to guarantee that a statement was indeed applied successfully before
-executing on the receiver.
-
-.. _replication_streams:
-
-Replication Streams
-###################
-
-The Drizzle kernel handles delivering replication messages to plugins by
-maintaining a list of replication streams. A stream is represented as a
-registered *replicator* and *applier* pair.
-
-When a replication message is generated within the kernel, the replication
-services module of the kernel will send this message to each registered
-*replicator*. The *replicator* will then do something useful with it and
-send it to each *applier* with which it is associated.
-
-Replicators
-***********
-
-A registered *replicator* is a plugin that implements the TransactionReplicator
-API. Each replicator will be plugged into the kernel to receive the Google
-Protobuf messages that are generated as the database is changed. Ideally,
-each registered replicator will transform or modify the messages it receives
-to implement a specific behavior. For example, filtering by schema name.
-
-Each registered replicator should have a unique name. The default replicator,
-cleverly named **default_replicator**, does no transformation at all on the
-replication messages.
-
-Appliers
-********
-
-A registered *applier* is a plugin that implements the TransactionApplier
-API. Appliers are responsible for applying the replication messages that it
-will receive from a registered replicator. The word "apply" is used loosely
-here. An applier may do anything with the replication messages that provides
-useful behavior. For example, an applier may simply write the messages to a
-file on disk, or it may send the messages over the network to some other
-service to be processed.
-
-At the point of registration with the Drizzle kernel, each applier specifies
-the name of a registered replicator that it should be attached to in order to
-make the replication stream pair.

=== added file 'docs/replication/drizzle.rst'
--- docs/replication/drizzle.rst	1970-01-01 00:00:00 +0000
+++ docs/replication/drizzle.rst	2011-10-23 05:45:09 +0000
@@ -0,0 +1,324 @@
+*******************
+Drizzle Replication
+*******************
+
+Replication events are recorded using messages in the `Google Protocol Buffer
+<http://code.google.com/p/protobuf/>`_ (GPB) format. GPB messages can contain
+sub-messages. There is a single main "envelope" message, Transaction, that
+is passed to plugins that subscribe to the replication stream.
+
+Configuration Options
+#####################
+
+**transaction_message_threshold**
+
+    Controls the size, in bytes, of the Transaction messages. When a Transaction
+    message exceeds this size, a new Transaction message with the same
+    transaction ID will be created to continue the replication events.
+    See :ref:`bulk-operations` below.
+
+
+**replicate_query**
+
+    Controls whether the originating SQL query will be included within each
+    Statement message contained in the enclosing Transaction message. The
+    default global value is FALSE which will not include the query in the
+    messages. It can be controlled per session, as well. For example:
+
+    .. code-block:: mysql
+
+       drizzle> set @@replicate_query = 1;
+
+    The stored query should be used as a guide only, and never executed
+    on a slave to perform replication as this will lead to incorrect results.
+
+Message Definitions
+###################
+
+The GPB messages are defined in .proto files in the drizzled/message
+directory of the Drizzle source code. The primary definition file is
+transaction.proto. Messages defined in this file are related in the
+following ways::
+
+
+  ------------------------------------------------------------------
+  |                                                                |
+  | Transaction message                                            |
+  |                                                                |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | TransactionContext message                              |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | Statement message 1                                     |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | Statement message 2                                     |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  |                             ...                                |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | Statement message N                                     |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  ------------------------------------------------------------------
+
+with each Statement message looking like so::
+
+  ------------------------------------------------------------------
+  |                                                                |
+  | Statement message                                              |
+  |                                                                |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | Common information                                      |  |
+  |   |                                                         |  |
+  |   |  - Type of Statement (INSERT, DELETE, etc)              |  |
+  |   |  - Start Timestamp                                      |  |
+  |   |  - End Timestamp                                        |  |
+  |   |  - (OPTIONAL) Actual SQL query string                   |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | Statement subclass message 1 (see below)                |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  |                             ...                                |
+  |   -----------------------------------------------------------  |
+  |   |                                                         |  |
+  |   | Statement subclass message N (see below)                |  |
+  |   |                                                         |  |
+  |   -----------------------------------------------------------  |
+  ------------------------------------------------------------------
+
+The Transaction Message
+#######################
+
+The main "envelope" message which represents an atomic transaction
+which changed the state of a server is the Transaction message class.
+
+The Transaction message contains two pieces:
+
+#. A TransactionContext message containing information about the
+   transaction as a whole, such as the ID of the executing server,
+   the start and end timestamp of the transaction, segmenting
+   metadata and a unique identifier for the transaction.
+#. A vector of Statement messages representing the distinct SQL
+   statements which modified the state of the server.  The Statement
+   message is, itself, a generic envelope message containing a
+   sub-message which describes the specific data modification which
+   occurred on the server (such as, for instance, an INSERT statement).
+
+The Statement Message
+#####################
+
+The generic "envelope" message containing information common to each
+SQL statement executed against a server (such as a start and end timestamp
+and the type of the SQL statement) as well as a Statement subclass message
+describing the specific data modification event on the server.
+
+Each Statement message contains a type member which indicates how readers
+of the Statement should construct the inner Statement subclass representing
+a data change.
+
+Statements are recorded separately as sometimes individual statements
+have to be rolled back.
+
+
+.. _bulk-operations:
+
+How Bulk Operations Work
+########################
+
+Certain operations which change large volumes of data on a server
+present a specific set of problems for a transaction coordinator or
+replication service. If all operations must complete atomically on a
+publishing server before replicas are delivered the complete
+transactional unit:
+
+#. The publishing server could consume a large amount of memory
+   building an in-memory Transaction message containing all the
+   operations contained  in the entire transaction.
+#. A replica, or subscribing server, is wasting time waiting on the
+   eventual completion (commit) of the large transaction on the
+   publishing server. It could be applying pieces of the large
+   transaction in the meantime...
+
+In order to prevent the problems inherent in (1) and (2) above, Drizzle's
+replication system uses a mechanism which provides bulk change
+operations.
+
+A single transaction in the database can possibly be represented with
+multiple protobuf Transaction messages if the message grows too large.
+This can happen if you have a bulk transaction, or a single statement
+affecting a very large number of rows, or just a large transaction with
+many statements/changes.
+
+For the first two examples, it is likely that the Statement sub-message
+itself will get segmented, causing another Transaction message to be
+created to hold the rest of the Statement's row changes. In these cases,
+it is enough to look at the segment information stored in the Statement
+message (see example below).
+
+For the last example, the Statement sub-messages may or may not be
+segmented, but we could still need to split the individual Statements up into
+multiple Transaction messages to keep the Transaction message size from
+growing too large. In this case, the segment information in the Statement
+submessages is not helpful if the Statement isn't segmented. We need this
+information in the Transaction message itself.
+
+Segmenting a Single SQL Statement
+*********************************
+
+When a regular SQL statement modifies or inserts more rows than a
+certain threshold, Drizzle's replication services component will begin
+sending Transaction messages to replicas which contain a chunk
+(or "segment") of the data which has been changed on the publisher.
+
+When data is inserted, updated, or modified in the database, a
+header containing information about modified tables and fields is
+matched with one or more data segments which contain the actual
+values changed in the statement.
+
+It's easiest to understand this mechanism by following through a real-world
+scenario.
+
+Suppose the following table:
+
+.. code-block:: mysql
+
+  CREATE TABLE test.person
+  (
+    id INT NOT NULL AUTO_INCREMENT PRIMARY KEY
+  , first_name VARCHAR(50)
+  , last_name VARCHAR(50)
+  , is_active CHAR(1) NOT NULL DEFAULT 'Y'
+  );
+
+Also suppose that test.t1 contains 1 million records.
+
+Next, suppose a client issues the SQL statement:
+
+.. code-block:: mysql
+
+  UPDATE test.person SET is_active = 'N';
+
+It is clear that one million records could be updated by this statement
+(we say, "could be" since Drizzle does not actually update a record if
+the UPDATE would not change the existing record...).
+
+In order to prevent the publishing server from having to construct an
+enormous Transaction message, Drizzle's replication services component
+will do the following:
+
+#. Construct a Transaction message with a transaction context containing
+   information about the originating server, the transaction ID, and
+   timestamp information.
+#. Construct an UpdateHeader message with information about the tables
+   and fields involved in the UPDATE statement.  Push this UpdateHeader
+   message onto the Transaction message's statement vector.
+#. Construct an UpdateData message.  Set the *segment_id* member to 1.
+   Set the *end_segment* member to true.
+#. For every record updated in a storage engine, the ReplicationServices
+   component builds a new UpdateRecord message and appends this message
+   to the aforementioned UpdateData message's record vector.
+#. After a certain threshold of records is reached, the
+   ReplicationServices component sets the current UpdateData message's
+   *end_segment* member to false, and proceeds to send the Transaction
+   message to replicators.
+#. The ReplicationServices component then constructs a new Transaction
+   message and constructs a transaction context with the same
+   transaction ID and server information.
+#. A new UpdateData message is created.  The message's *segment_id* is
+   set to N+1 and as new records are updated, new UpdateRecord messages
+   are appended to the UpdateData message's record vector.
+#. While records are being updated, we repeat steps 5 through 7, with
+   only the final UpdateData message having its *end_segment* member set
+   to true.
+
+Segmenting a Transaction
+************************
+
+The Transaction protobuf message also contains *segment_id* member and a
+*end_segment* member. These values are also set appropriately when a
+Statement sub-message is segmented, as described above.
+
+These values are also set when a Transaction must be segmented along
+individual Statement boundaries (i.e., the Statement message itself
+is **not** segmented). In either case, it is enough to check the
+*end_segment* and *segment_id* values of the Transaction message
+to determine if this is a multi-message transaction.
+
+Handling ROLLBACKs
+##################
+
+Both transactions and individual statements may be rolled back.
+
+When a transaction is rolled back, one of two things happen depending
+on whether the transaction is made up of either a single Transaction
+message, or if it is made up of multiple Transaction messages (e.g, bulk
+load).
+
+* For a transaction encapsulated entirely within a single Transaction
+  message, the entire message is simply discarded and not sent through
+  the replication stream.
+* For a transaction which is made up of multiple messages, and at least
+  one message has already been sent through the replication stream, then
+  the Transaction message will contain a Statement message with type =
+  ROLLBACK. This signifies to rollback the entire transaction.
+
+A special Statement message type, ROLLBACK_STATEMENT, is used when
+we have a segmented Statement message (see above) and we need to tell the
+receiver to undo any changes made for this single statement, but not
+for the entire transaction. If the receiver cannot handle rolling back
+a single statement, then a message buffering strategy should be employed 
+to guarantee that a statement was indeed applied successfully before
+executing on the receiver.
+
+.. _replication_streams:
+
+Replication Streams
+###################
+
+The Drizzle kernel handles delivering replication messages to plugins by
+maintaining a list of replication streams. A stream is represented as a
+registered *replicator* and *applier* pair.
+
+When a replication message is generated within the kernel, the replication
+services module of the kernel will send this message to each registered
+*replicator*. The *replicator* will then do something useful with it and
+send it to each *applier* with which it is associated.
+
+Replicators
+***********
+
+A registered *replicator* is a plugin that implements the TransactionReplicator
+API. Each replicator will be plugged into the kernel to receive the Google
+Protobuf messages that are generated as the database is changed. Ideally,
+each registered replicator will transform or modify the messages it receives
+to implement a specific behavior. For example, filtering by schema name.
+
+Each registered replicator should have a unique name. The default replicator,
+cleverly named **default_replicator**, does no transformation at all on the
+replication messages.
+
+Appliers
+********
+
+A registered *applier* is a plugin that implements the TransactionApplier
+API. Appliers are responsible for applying the replication messages that it
+will receive from a registered replicator. The word "apply" is used loosely
+here. An applier may do anything with the replication messages that provides
+useful behavior. For example, an applier may simply write the messages to a
+file on disk, or it may send the messages over the network to some other
+service to be processed.
+
+At the point of registration with the Drizzle kernel, each applier specifies
+the name of a registered replicator that it should be attached to in order to
+make the replication stream pair.

=== modified file 'docs/versioning.rst'
--- docs/versioning.rst	2011-03-02 23:58:31 +0000
+++ docs/versioning.rst	2011-10-23 05:45:09 +0000
@@ -1,8 +1,11 @@
 Releases and Versioning
-========================
-
-A new version of Drizzle is released every two weeks. The release is labelled "YEAR-MONTH-REVISION#"
-
-This shouldn't be confused with "YEAR-MONTH-DAY". For example, in "2011-02-10" the "10" refers to the revision number and not the date.
-
-You can always see the latest release on Launchpad. 
\ No newline at end of file
+=======================
+
+New development versions of Drizzle are released every two weeks.
+Releases are labelled ``YEAR-MONTH-REVISION``  This should not be
+confused with ``YEAR-MONTH-DAY``.  For example, version
+``2011.02.10`` refers to February 2011 *revision* 10.
+
+Development releases are available through Lanchpad at https://launchpad.net/drizzle/+download.
+
+Subscribe to http://planetdrizzle.org/ or the `Drizzle Discuss mailing list <https://launchpad.net/~drizzle-discuss/>`_ to be notified about all releases.

=== modified file 'plugin/ascii/docs/index.rst'
--- plugin/ascii/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/ascii/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _ascii_plugin:
+
 ASCII Function
 ==============
 

=== modified file 'plugin/auth_all/docs/index.rst'
--- plugin/auth_all/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/auth_all/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _auth_all_plugin:
+
 Allow All Authentication
 ========================
 

=== modified file 'plugin/auth_file/docs/index.rst'
--- plugin/auth_file/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/auth_file/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _auth_file_plugin:
+
 File-based Authentication
 =========================
 

=== modified file 'plugin/auth_http/docs/index.rst'
--- plugin/auth_http/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/auth_http/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _auth_http_plugin:
+
 HTTP Authentication
 ===================
 

=== modified file 'plugin/auth_ldap/docs/index.rst'
--- plugin/auth_ldap/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/auth_ldap/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _auth_ldap_plugin:
+
 LDAP Authentication
 ===================
 

=== modified file 'plugin/auth_pam/docs/index.rst'
--- plugin/auth_pam/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/auth_pam/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _auth_pam_plugin:
+
 PAM Authenication
 =================
 

=== modified file 'plugin/benchmark/docs/index.rst'
--- plugin/benchmark/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/benchmark/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _benchmark_plugin:
+
 BENCHMARK Function
 ==================
 

=== modified file 'plugin/catalog/docs/index.rst'
--- plugin/catalog/docs/index.rst	2011-08-13 20:41:38 +0000
+++ plugin/catalog/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _catalog_plugin:
+
 Catalog System
 ==============
 

=== modified file 'plugin/charlength/docs/index.rst'
--- plugin/charlength/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/charlength/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _charlength_plugin:
+
 CHAR_LENGTH Function
 ====================
 

=== modified file 'plugin/coercibility_function/docs/index.rst'
--- plugin/coercibility_function/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/coercibility_function/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _coercibility_function_plugin:
+
 COERCIBILITY Function
 =====================
 

=== modified file 'plugin/collation_dictionary/docs/index.rst'
--- plugin/collation_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/collation_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _collation_dictionary_plugin:
+
 Character and Collation Dictionary
 ==================================
 

=== modified file 'plugin/compression/docs/index.rst'
--- plugin/compression/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/compression/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _compression_plugin:
+
 Compression Functions
 =====================
 

=== modified file 'plugin/connection_id/docs/index.rst'
--- plugin/connection_id/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/connection_id/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _connection_id_plugin:
+
 CONNECTION_ID Function
 ======================
 

=== modified file 'plugin/crc32/docs/index.rst'
--- plugin/crc32/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/crc32/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _crc32_plugin:
+
 CRC32 Function
 ==============
 

=== modified file 'plugin/debug/docs/index.rst'
--- plugin/debug/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/debug/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _debug_plugin:
+
 Debugging Functions
 ===================
 

=== modified file 'plugin/default_replicator/docs/index.rst'
--- plugin/default_replicator/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/default_replicator/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,10 +1,12 @@
+.. _default_replicator_plugin:
+
 Default Replicator
 ==================
 
 :program:`default_replicator` is a simple replicator which replicates all
 write events to all appliers.
 
-.. seealso:: :doc:`/replication`
+.. seealso:: :doc:`/replication/drizzle`
 
 .. _default_replicator_loading:
 

=== modified file 'plugin/drizzle_protocol/docs/index.rst'
--- plugin/drizzle_protocol/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/drizzle_protocol/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _drizzle_protocol_plugin:
+
 Drizzle Protocol
 ================
 

=== modified file 'plugin/errmsg_stderr/docs/index.rst'
--- plugin/errmsg_stderr/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/errmsg_stderr/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _errmsg_stderr_plugin:
+
 Error Messages To STDERR
 ========================
 

=== modified file 'plugin/error_dictionary/docs/index.rst'
--- plugin/error_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/error_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _error_dictionary_plugin:
+
 Error Dictionary
 ================
 

=== modified file 'plugin/filtered_replicator/docs/index.rst'
--- plugin/filtered_replicator/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/filtered_replicator/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _filtered_replicator_plugin:
+
 Filtered Replicator
 ===================
 

=== modified file 'plugin/function_dictionary/docs/index.rst'
--- plugin/function_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/function_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _function_dictionary_plugin:
+
 Function Dictionary
 ===================
 

=== modified file 'plugin/function_engine/docs/index.rst'
--- plugin/function_engine/docs/index.rst	2011-08-13 20:41:38 +0000
+++ plugin/function_engine/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _function_engine_plugin:
+
 Function Engine
 ===============
 

=== modified file 'plugin/hex_functions/docs/index.rst'
--- plugin/hex_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/hex_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _hex_functions_plugin:
+
 Hex Functions
 =============
 

=== modified file 'plugin/http_functions/docs/index.rst'
--- plugin/http_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/http_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _http_functions_plugin:
+
 HTTP Functions
 ==============
 

=== modified file 'plugin/information_schema_dictionary/docs/index.rst'
--- plugin/information_schema_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/information_schema_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _information_schema_dictionary_plugin:
+
 Information Schema Dictionary
 =============================
 

=== modified file 'plugin/innobase/docs/index.rst'
--- plugin/innobase/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/innobase/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _innobase_plugin:
+
 InnoDB Storage Engine
 =====================
 

=== modified file 'plugin/json_server/docs/index.rst'
--- plugin/json_server/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/json_server/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _json_server_plugin:
+
 JSON Server
 ===========
 

=== modified file 'plugin/length/docs/index.rst'
--- plugin/length/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/length/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _length_plugin:
+
 Length Functions
 ================
 

=== modified file 'plugin/logging_gearman/docs/index.rst'
--- plugin/logging_gearman/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/logging_gearman/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _logging_gearman_plugin:
+
 Gearman Logging
 ===============
 

=== modified file 'plugin/logging_query/docs/index.rst'
--- plugin/logging_query/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/logging_query/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _logging_query_plugin:
+
 Query Logging
 =============
 

=== modified file 'plugin/logging_stats/docs/index.rst'
--- plugin/logging_stats/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/logging_stats/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _logging_stats_plugin:
+
 User Statistics
 ===============
 

=== modified file 'plugin/math_functions/docs/index.rst'
--- plugin/math_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/math_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _math_functions_plugin:
+
 Math Functions
 ==============
 

=== modified file 'plugin/md5/docs/index.rst'
--- plugin/md5/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/md5/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _md5_plugin:
+
 MD5 Function
 ============
 

=== modified file 'plugin/memcached_functions/docs/index.rst'
--- plugin/memcached_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/memcached_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _memcached_functions_plugin:
+
 Memcached Functions
 ===================
 

=== modified file 'plugin/memcached_stats/docs/index.rst'
--- plugin/memcached_stats/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/memcached_stats/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _memcached_stats_plugin:
+
 Memcached Statistics
 ====================
 

=== modified file 'plugin/memory/docs/index.rst'
--- plugin/memory/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/memory/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _memory_plugin:
+
 Memory Storage Engine
 =====================
 

=== modified file 'plugin/multi_thread/docs/index.rst'
--- plugin/multi_thread/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/multi_thread/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _multi_thread_plugin:
+
 Multi-Thread Scheduler
 ======================
 

=== modified file 'plugin/myisam/docs/index.rst'
--- plugin/myisam/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/myisam/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _myisam_plugin:
+
 MyISAM Storage Engine
 =====================
 

=== modified file 'plugin/mysql_protocol/docs/index.rst'
--- plugin/mysql_protocol/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/mysql_protocol/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _mysql_protocol_plugin:
+
 MySQL Protocol
 ==============
 

=== modified file 'plugin/mysql_unix_socket_protocol/docs/index.rst'
--- plugin/mysql_unix_socket_protocol/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/mysql_unix_socket_protocol/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _mysql_unix_socket_protocol_plugin:
+
 MySQL Unix Socket Protocol
 ==========================
 

=== modified file 'plugin/pbms/docs/index.rst'
--- plugin/pbms/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/pbms/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _pbms_plugin:
+
 PrimeBase Media Stream Daemon
 =============================
 

=== modified file 'plugin/performance_dictionary/docs/index.rst'
--- plugin/performance_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/performance_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _performance_dictionary_plugin:
+
 Performance Dictionary
 ======================
 

=== modified file 'plugin/protocol_dictionary/docs/index.rst'
--- plugin/protocol_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/protocol_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _protocol_dictionary_plugin:
+
 Protocol Dictionary
 ===================
 

=== modified file 'plugin/query_log/docs/index.rst'
--- plugin/query_log/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/query_log/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _query_log_plugin:
+
 Query Log
 =========
 

=== modified file 'plugin/rabbitmq/docs/index.rst'
--- plugin/rabbitmq/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/rabbitmq/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _rabbitmq_plugin:
+
 RabbitMQ Integration
 ======================
 

=== modified file 'plugin/rand_function/docs/index.rst'
--- plugin/rand_function/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/rand_function/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _rand_function_plugin:
+
 RAND Function
 =============
 

=== modified file 'plugin/regex_policy/docs/index.rst'
--- plugin/regex_policy/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/regex_policy/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _regex_policy_plugin:
+
 Regex-based Authorization
 =========================
 

=== modified file 'plugin/registry_dictionary/docs/index.rst'
--- plugin/registry_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/registry_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _registry_dictionary_plugin:
+
 Registry Dictionary
 ===================
 

=== modified file 'plugin/replication_dictionary/docs/index.rst'
--- plugin/replication_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/replication_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _replication_dictionary_plugin:
+
 Replication Dictionary
 ======================
 

=== modified file 'plugin/reverse_function/docs/index.rst'
--- plugin/reverse_function/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/reverse_function/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _reverse_function_plugin:
+
 REVERSE Function
 ================
 

=== modified file 'plugin/schema_dictionary/docs/index.rst'
--- plugin/schema_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/schema_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _schema_dictionary_plugin:
+
 Schema Dictionary
 =================
 

=== modified file 'plugin/schema_engine/docs/index.rst'
--- plugin/schema_engine/docs/index.rst	2011-09-03 22:25:16 +0000
+++ plugin/schema_engine/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _schema_engine_plugin:
+
 Schema Engine
 =============
 

=== modified file 'plugin/session_dictionary/docs/index.rst'
--- plugin/session_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/session_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _session_dictionary_plugin:
+
 Session Dictionary
 ==================
 

=== modified file 'plugin/show_dictionary/docs/index.rst'
--- plugin/show_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/show_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _show_dictionary_plugin:
+
 SHOW Commands
 =============
 

=== modified file 'plugin/show_schema_proto/docs/index.rst'
--- plugin/show_schema_proto/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/show_schema_proto/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _show_schema_proto_plugin:
+
 SHOW_SCHEMA_PROTO Function
 ==========================
 

=== modified file 'plugin/shutdown_function/docs/index.rst'
--- plugin/shutdown_function/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/shutdown_function/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _shutdown_function_plugin:
+
 SHUTDOWN Function
 =================
 

=== modified file 'plugin/signal_handler/docs/index.rst'
--- plugin/signal_handler/docs/index.rst	2011-09-03 22:25:16 +0000
+++ plugin/signal_handler/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _signal_handler_plugin:
+
 Signal Handler
 ==============
 

=== modified file 'plugin/simple_user_policy/docs/index.rst'
--- plugin/simple_user_policy/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/simple_user_policy/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _simple_user_policy_plugin:
+
 User-based Authorization
 ========================
 

=== modified file 'plugin/slave/docs/index.rst'
--- plugin/slave/docs/index.rst	2011-09-03 22:25:16 +0000
+++ plugin/slave/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _slave_plugin:
+
 Replication Slave
 ==================
 

=== modified file 'plugin/sleep/docs/index.rst'
--- plugin/sleep/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/sleep/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _sleep_plugin:
+
 SLEEP Function
 ==============
 

=== modified file 'plugin/status_dictionary/docs/index.rst'
--- plugin/status_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/status_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _status_dictionary_plugin:
+
 Status Dictionary
 =================
 

=== modified file 'plugin/string_functions/docs/index.rst'
--- plugin/string_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/string_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _string_functions_plugin:
+
 String Functions
 ================
 

=== modified file 'plugin/substr_functions/docs/index.rst'
--- plugin/substr_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/substr_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _substr_functions_plugin:
+
 Substring Functions
 ===================
 

=== modified file 'plugin/syslog/docs/index.rst'
--- plugin/syslog/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/syslog/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _syslog_plugin:
+
 Syslog
 ======
 

=== modified file 'plugin/table_cache_dictionary/docs/index.rst'
--- plugin/table_cache_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/table_cache_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _table_cache_dictionary_plugin:
+
 Table Cache Dictionary
 ======================
 

=== modified file 'plugin/transaction_log/docs/index.rst'
--- plugin/transaction_log/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/transaction_log/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _transaction_log_plugin:
+
 Transaction Log
 ===============
 
@@ -163,8 +165,7 @@
 ------------------------
 
 Replication events are recorded using messages in the `Google Protocol Buffer
-<http://code.google.com/p/protobuf/>`_ (GPB) format. See the :doc:`Replication
-documentation </replication>` for more information.
+<http://code.google.com/p/protobuf/>`_ (GPB) format. See :doc:`/replication/drizzle` for more information.
 
 Transaction Log Format
 ----------------------

=== modified file 'plugin/trigger_dictionary/docs/index.rst'
--- plugin/trigger_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/trigger_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _trigger_dictionary_plugin:
+
 Trigger Dictionary
 ==================
 

=== modified file 'plugin/user_locks/docs/index.rst'
--- plugin/user_locks/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/user_locks/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _user_locks_plugin:
+
 User Locks
 ==========
 

=== modified file 'plugin/utility_dictionary/docs/index.rst'
--- plugin/utility_dictionary/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/utility_dictionary/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _utility_dictionary_plugin:
+
 Utility Dictionary
 ==================
 

=== modified file 'plugin/utility_functions/docs/index.rst'
--- plugin/utility_functions/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/utility_functions/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _utility_functions_plugin:
+
 Utility Functions
 =================
 

=== modified file 'plugin/uuid_function/docs/index.rst'
--- plugin/uuid_function/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/uuid_function/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _uuid_function_plugin:
+
 UUID Function
 =============
 

=== modified file 'plugin/version/docs/index.rst'
--- plugin/version/docs/index.rst	2011-10-02 06:29:23 +0000
+++ plugin/version/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _version_plugin:
+
 VERSION Function
 ================
 

=== modified file 'plugin/zeromq/docs/index.rst'
--- plugin/zeromq/docs/index.rst	2011-09-03 22:25:16 +0000
+++ plugin/zeromq/docs/index.rst	2011-10-23 05:45:09 +0000
@@ -1,3 +1,5 @@
+.. _zeromq_plugin:
+
 ZeroMQ
 ======
 

